@@ -1,19 +1,16 @@
 """Tornado handlers for logging into the Jupyter Server."""
-
 # Copyright (c) Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
-
-import re
 import os
+import re
 import uuid
-
 from urllib.parse import urlparse
 
 from tornado.escape import url_escape
 
-from .security import passwd_check, set_password
-
 from ..base.handlers import JupyterHandler
+from .security import passwd_check
+from .security import set_password
 
 
 class LoginHandler(JupyterHandler):
@@ -21,11 +18,15 @@ class LoginHandler(JupyterHandler):
 
     authenticates with a hashed password from the configuration.
     """
+
     def _render(self, message=None):
-        self.write(self.render_template('login.html',
-                next=url_escape(self.get_argument('next', default=self.base_url)),
+        self.write(
+            self.render_template(
+                "login.html",
+                next=url_escape(self.get_argument("next", default=self.base_url)),
                 message=message,
-        ))
+            )
+        )
 
     def _redirect_safe(self, url, default=None):
         """Redirect if url is on our PATH
@@ -47,7 +48,7 @@ class LoginHandler(JupyterHandler):
             # OR pass our cross-origin check
             if parsed.netloc:
                 # if full URL, run our cross-origin check:
-                origin = '%s://%s' % (parsed.scheme, parsed.netloc)
+                origin = "%s://%s" % (parsed.scheme, parsed.netloc)
                 origin = origin.lower()
                 if self.allow_origin:
                     allow = self.allow_origin == origin
@@ -61,7 +62,7 @@ class LoginHandler(JupyterHandler):
 
     def get(self):
         if self.current_user:
-            next_url = self.get_argument('next', default=self.base_url)
+            next_url = self.get_argument("next", default=self.base_url)
             self._redirect_safe(next_url)
         else:
             self._render()
@@ -74,8 +75,8 @@ class LoginHandler(JupyterHandler):
         return passwd_check(a, b)
 
     def post(self):
-        typed_password = self.get_argument('password', default=u'')
-        new_password = self.get_argument('new_password', default=u'')
+        typed_password = self.get_argument("password", default=u"")
+        new_password = self.get_argument("new_password", default=u"")
 
         if self.get_login_available(self.settings):
             if self.passwd_check(self.hashed_password, typed_password) and not new_password:
@@ -84,34 +85,31 @@ class LoginHandler(JupyterHandler):
                 self.set_login_cookie(self, uuid.uuid4().hex)
                 if new_password and self.settings.get("allow_password_change"):
                     config_dir = self.settings.get("config_dir")
-                    config_file = os.path.join(
-                        config_dir, "jupyter_server_config.json"
-                    )
+                    config_file = os.path.join(config_dir, "jupyter_server_config.json")
                     set_password(new_password, config_file=config_file)
                     self.log.info("Wrote hashed password to %s" % config_file)
             else:
                 self.set_status(401)
-                self._render(message={'error': 'Invalid credentials'})
+                self._render(message={"error": "Invalid credentials"})
                 return
 
-
-        next_url = self.get_argument('next', default=self.base_url)
+        next_url = self.get_argument("next", default=self.base_url)
         self._redirect_safe(next_url)
 
     @classmethod
     def set_login_cookie(cls, handler, user_id=None):
         """Call this on handlers to set the login cookie for success"""
-        cookie_options = handler.settings.get('cookie_options', {})
-        cookie_options.setdefault('httponly', True)
+        cookie_options = handler.settings.get("cookie_options", {})
+        cookie_options.setdefault("httponly", True)
         # tornado <4.2 has a bug that considers secure==True as soon as
         # 'secure' kwarg is passed to set_secure_cookie
-        if handler.settings.get('secure_cookie', handler.request.protocol == 'https'):
-            cookie_options.setdefault('secure', True)
-        cookie_options.setdefault('path', handler.base_url)
+        if handler.settings.get("secure_cookie", handler.request.protocol == "https"):
+            cookie_options.setdefault("secure", True)
+        cookie_options.setdefault("path", handler.base_url)
         handler.set_secure_cookie(handler.cookie_name, user_id, **cookie_options)
         return user_id
 
-    auth_header_pat = re.compile('token\s+(.+)', re.IGNORECASE)
+    auth_header_pat = re.compile("token\s+(.+)", re.IGNORECASE)
 
     @classmethod
     def get_token(cls, handler):
@@ -123,10 +121,10 @@ class LoginHandler(JupyterHandler):
         - in header: Authorization: token <token>
         """
 
-        user_token = handler.get_argument('token', '')
+        user_token = handler.get_argument("token", "")
         if not user_token:
             # get it from Authorization header
-            m = cls.auth_header_pat.match(handler.request.headers.get('Authorization', ''))
+            m = cls.auth_header_pat.match(handler.request.headers.get("Authorization", ""))
             if m:
                 user_token = m.group(1)
         return user_token
@@ -153,10 +151,10 @@ class LoginHandler(JupyterHandler):
         - xsrf protection
         - skip origin-checks for scripts
         """
-        if getattr(handler, '_user_id', None) is None:
+        if getattr(handler, "_user_id", None) is None:
             # ensure get_user has been called, so we know if we're token-authenticated
             handler.get_current_user()
-        return getattr(handler, '_token_authenticated', False)
+        return getattr(handler, "_token_authenticated", False)
 
     @classmethod
     def get_user(cls, handler):
@@ -166,12 +164,14 @@ class LoginHandler(JupyterHandler):
         """
         # Can't call this get_current_user because it will collide when
         # called on LoginHandler itself.
-        if getattr(handler, '_user_id', None):
+        if getattr(handler, "_user_id", None):
             return handler._user_id
         user_id = cls.get_user_token(handler)
         if user_id is None:
-            get_secure_cookie_kwargs  = handler.settings.get('get_secure_cookie_kwargs', {})
-            user_id = handler.get_secure_cookie(handler.cookie_name, **get_secure_cookie_kwargs )
+            get_secure_cookie_kwargs = handler.settings.get("get_secure_cookie_kwargs", {})
+            user_id = handler.get_secure_cookie(handler.cookie_name, **get_secure_cookie_kwargs)
+            if user_id:
+                user_id = user_id.decode()
         else:
             cls.set_login_cookie(handler, user_id)
             # Record that the current request has been authenticated with a token.
@@ -187,7 +187,7 @@ class LoginHandler(JupyterHandler):
             if not handler.login_available:
                 # Completely insecure! No authentication at all.
                 # No need to warn here, though; validate_security will have already done that.
-                user_id = 'anonymous'
+                user_id = "anonymous"
 
         # cache value for future retrievals on the same request
         handler._user_id = user_id
@@ -196,7 +196,7 @@ class LoginHandler(JupyterHandler):
     @classmethod
     def get_user_token(cls, handler):
         """Identify the user based on a token in the URL or Authorization header
-        
+
         Returns:
         - uuid if authenticated
         - None if not
@@ -209,7 +209,9 @@ class LoginHandler(JupyterHandler):
         authenticated = False
         if user_token == token:
             # token-authenticated, set the login cookie
-            handler.log.debug("Accepting token-authenticated connection from %s", handler.request.remote_ip)
+            handler.log.debug(
+                "Accepting token-authenticated connection from %s", handler.request.remote_ip
+            )
             authenticated = True
 
         if authenticated:
@@ -217,7 +219,6 @@ class LoginHandler(JupyterHandler):
         else:
             return None
 
-
     @classmethod
     def validate_security(cls, app, ssl_options=None):
         """Check the application's security.
@@ -227,16 +228,18 @@ class LoginHandler(JupyterHandler):
         if not app.ip:
             warning = "WARNING: The Jupyter server is listening on all IP addresses"
             if ssl_options is None:
-                app.log.warning(warning + " and not using encryption. This "
-                    "is not recommended.")
+                app.log.warning(warning + " and not using encryption. This " "is not recommended.")
             if not app.password and not app.token:
-                app.log.warning(warning + " and not using authentication. "
-                    "This is highly insecure and not recommended.")
+                app.log.warning(
+                    warning + " and not using authentication. "
+                    "This is highly insecure and not recommended."
+                )
         else:
             if not app.password and not app.token:
                 app.log.warning(
                     "All authentication is disabled."
-                    "  Anyone who can connect to this server will be able to run code.")
+                    "  Anyone who can connect to this server will be able to run code."
+                )
 
     @classmethod
     def password_from_settings(cls, settings):
@@ -244,9 +247,9 @@ class LoginHandler(JupyterHandler):
 
         If there is no configured password, an empty string will be returned.
         """
-        return settings.get('password', u'')
+        return settings.get("password", u"")
 
     @classmethod
     def get_login_available(cls, settings):
         """Whether this LoginHandler is needed - and therefore whether the login page should be displayed."""
-        return bool(cls.password_from_settings(settings) or settings.get('token'))
+        return bool(cls.password_from_settings(settings) or settings.get("token"))
